==> haskell-either-5.0.3-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-3ucGpqzZEQ8FfeZNWDJLth
key:                  either-5.0.3-3ucGpqzZEQ8FfeZNWDJLth
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  afee5f8aff2a75596ad0c5b00113a55b
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-3ucGpqzZEQ8FfeZNWDJLth
depends:
    base-4.17.2.1 bifunctors-5.6.2-B9wj2UEf2xa949Ragriipa mtl-2.2.2
    profunctors-5.6.3-8FNppvPYojn1YMtMW6wR6o
    semigroupoids-6.0.1-FMYBJOyO4ro7UvayiHjr7b

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-Kx5w7TTJpC6LAET8edNsqP
key:                  either-5.0.3-Kx5w7TTJpC6LAET8edNsqP
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  b460b07614fa072ee7b10eea99403d5a
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-Kx5w7TTJpC6LAET8edNsqP
depends:
    base-4.17.2.1 bifunctors-5.6.2-6G3MzOxzgCeKYhsSjlhJ0F mtl-2.2.2
    profunctors-5.6.3-L21qmF9iXw2FcRafgVQ9Hj
    semigroupoids-6.0.1-8sKf1o1a2c6K4GAi4qlWGt

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
